@@ -129,7 +129,8 @@ class bfit(object):
                             "Matched Helicity","Histograms"),
                       '1f':("Combined Helicity","Split Helicity","Raw Scans",
                             "Positive Helicity","Negative Helicity",
-                            "Shifted Split","Shifted Combined","Histograms"),
+                            "Shifted Split","Shifted Combined","Normalized Combined",
+                            "Histograms"),
                       '1n':("Combined Helicity","Split Helicity","Raw Scans",
                             "Positive Helicity","Negative Helicity",
                             "Matched Peak Finding","Histograms"),
@@ -138,7 +139,7 @@ class bfit(object):
                             "Histograms"),
                       '1w':("Combined Helicity","Split Helicity","Raw Scans",
                             "Positive Helicity","Negative Helicity",
-                            "Shifted Split","Shifted Combined","Histograms"),
+                            "Shifted Split","Shifted Combined","Normalized Combined","Histograms"),
                       '2e':("Combined Hel Slopes","Combined Hel Diff","Combined Hel Raw",
                             "Split Hel Slopes","Split Hel Diff","Split Hel Raw",
                             "Split Slopes Shifted","Split Diff Shifted","Split Raw Shifted"),
@@ -158,6 +159,7 @@ class bfit(object):
                  "Matched Helicity"         :'hm',
                  "Shifted Split"            :'hs',
                  "Shifted Combined"         :'cs',
+                 "Normalized Combined"      :'cn',
                  "Matched Peak Finding"     :'hp',
                  "Raw Scans"                :'r',
                  "Histograms"               :'rhist',
@@ -189,8 +191,9 @@ class bfit(object):
                  
     ylabel_dict={'ad':r'$N_\alpha/N_\beta$', # otherwise, label as Asymmetry
                  'adn':r'$N_\alpha/N_\beta$', 
-                 'hs':r'Asym-Asym($\nu_{min}$)',
-                 'cs':r'Asym-Asym($\nu_{min}$)',
+                 'hs':r'Asym-Asym($\nu_\mathrm{max}$)',
+                 'cs':r'Asym-Asym($\nu_\mathrm{max}$)',
+                 'cn':r'Asym/Asym($\nu_\mathrm{max}$)',
                  'rhist':'Counts'}
     
     # histogram names for x axis
@@ -470,9 +473,9 @@ class bfit(object):
         noteframe.rowconfigure(0,weight=1)
         
         # Notetabs
-        self.fileviewer = fileviewer(file_viewer_tab,wref.proxy(self))
-        self.fetch_files = fetch_files(fetch_files_tab,wref.proxy(self))
-        self.fit_files = fit_files(fit_files_tab,wref.proxy(self))
+        self.fileviewer = fileviewer(file_viewer_tab, wref.proxy(self))
+        self.fetch_files = fetch_files(fetch_files_tab, wref.proxy(self))
+        self.fit_files = fit_files(fit_files_tab, wref.proxy(self))
         
         # set instance variables ---------------------------------------------
         self.mainframe = mainframe
@@ -791,19 +794,31 @@ class bfit(object):
                 # remove zero asym
                 ap = a.p[0]
                 an = a.n[0]
+                dap = a.p[1]
+                dan = a.n[1]
                 tag_p = ap!=0
                 tag_n = an!=0
                 ap = ap[tag_p]
                 an = an[tag_n]
+                dap = dap[tag_p]
+                dan = dan[tag_n]
                 
-                # subtract first value
-                loc = np.where(x==min(x))[0][0]
-                ap -= ap[loc]
-                an -= an[loc]
+                # subtract last 5 values
+                end = np.average(ap[-5:],weights=1/dap[-5:]**2)
+                dend = 1/np.sum(1/dap[-5:]**2)**0.5
                 
-                self.plt.errorbar(figstyle,data.id,x[tag_p],ap,a.p[1][tag_p],
+                ap -= end
+                dap = ((dend)**2+(dap)**2)**0.5
+                
+                end = np.average(an[-5:],weights=1/dan[-5:]**2)
+                dend = 1/np.sum(1/dan[-5:]**2)**0.5
+                
+                an -= end
+                dan = ((dend)**2+(dan)**2)**0.5
+                
+                self.plt.errorbar(figstyle,data.id,x[tag_p],ap,dap,
                         label=label+" ($+$)",**drawargs)
-                self.plt.errorbar(figstyle,data.id,x[tag_n],an,a.n[1][tag_n],
+                self.plt.errorbar(figstyle,data.id,x[tag_n],an,dan,
                         label=label+" ($-$)",unique=False,**drawargs)
                 
             # plot split helicities, flipped about the average
@@ -879,15 +894,42 @@ class bfit(object):
                 
                 # remove zero asym
                 ac = a.c[0]
+                dac = a.c[1]
                 tag = ac!=0
                 ac = ac[tag]
+                dac = dac[tag]
                 
-                # subtract first value
+                # subtract last 5 values
                 x = x[tag]
-                loc = np.where(x==min(x))[0][0]
-                ac -= ac[loc]
                 
-                self.plt.errorbar(figstyle,data.id,x,ac,a.c[1][tag],label=label,**drawargs)
+                end = np.average(ac[-5:],weights=1/dac[-5:]**2)
+                dend = 1/np.sum(1/dac[-5:]**2)**0.5
+                
+                ac -= end
+                dac = ((dend)**2+(dac)**2)**0.5
+                
+                self.plt.errorbar(figstyle,data.id,x,ac,dac,label=label,**drawargs)
+                
+            # plot combined helicities, normalized by baseline
+            elif asym_type == 'cn':
+                
+                # remove zero asym
+                ac = a.c[0]
+                dac = a.c[1]
+                tag = ac!=0
+                ac = ac[tag]
+                dac = dac[tag]
+                
+                # divide by last value
+                x = x[tag]
+                
+                end = np.average(ac[-5:],weights=1/dac[-5:]**2)
+                dend = 1/np.sum(1/dac[-5:]**2)**0.5
+                
+                dac = ac/end * ((dend/end)**2 + (dac/ac)**2)**0.5
+                ac /= end
+                
+                self.plt.errorbar(figstyle,data.id,x,ac,dac,label=label,**drawargs)
                 
             # attempting to draw raw scans unlawfully
             elif asym_type == 'r':
